==> kubernetes-model-storageclass-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/VolumeNodeResourcesFluentImpl.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class VolumeNodeResourcesFluentImpl<A extends io.fabric8.kubernetes.api.model.storage.v1beta1.VolumeNodeResourcesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.storage.v1beta1.VolumeNodeResourcesFluent<A>{
  public VolumeNodeResourcesFluentImpl() {
  }
  public VolumeNodeResourcesFluentImpl(io.fabric8.kubernetes.api.model.storage.v1beta1.VolumeNodeResources instance) {
    this.withCount(instance.getCount()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer count;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getCount() {
    return this.count;
  }
  public A withCount(java.lang.Integer count) {
    this.count=count; return (A) this;
  }
  public java.lang.Boolean hasCount() {
    return this.count != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VolumeNodeResourcesFluentImpl that = (VolumeNodeResourcesFluentImpl) o;
    if (count != null ? !count.equals(that.count) :that.count != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(count,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-storageclass-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/VolumeNodeResourcesFluentImpl.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class VolumeNodeResourcesFluentImpl<A extends io.fabric8.kubernetes.api.model.storage.v1beta1.VolumeNodeResourcesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.storage.v1beta1.VolumeNodeResourcesFluent<A>{
  public VolumeNodeResourcesFluentImpl() {
  }
  public VolumeNodeResourcesFluentImpl(io.fabric8.kubernetes.api.model.storage.v1beta1.VolumeNodeResources instance) {
    this.withCount(instance.getCount()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer count;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getCount() {
    return this.count;
  }
  public A withCount(java.lang.Integer count) {
    this.count=count; return (A) this;
  }
  public java.lang.Boolean hasCount() {
    return this.count != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VolumeNodeResourcesFluentImpl that = (VolumeNodeResourcesFluentImpl) o;
    if (count != null ? !count.equals(that.count) :that.count != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(count,  additionalProperties,  super.hashCode());
  }
  
}
